@@ -5,10 +5,12 @@ from cognite.client.exceptions import CogniteAPIError
 from cognite.experimental import CogniteClient
 from cognite.experimental.data_classes import Function
 from requests.exceptions import ConnectionError
-from urllib3.exceptions import MaxRetryError, ReadTimeoutError
 
 from cognite.airworkflow.util import cdf, env
 
+# from urllib3.exceptions import MaxRetryError, ReadTimeoutError
+
+
 CHANNEL = "model_deployment_fails"
 
 
@@ -66,13 +68,14 @@ def deploy_function(
             )
             x = 3
         except (
-            TimeoutError,
-            ReadTimeoutError,
+            # TimeoutError,
+            # ReadTimeoutError,
             CogniteAPIError,
-            MaxRetryError,
+            # MaxRetryError,
             ConnectionError,
-            AttributeError,
+            # AttributeError,
         ) as e:
+            print(e)
             if isinstance(e, CogniteAPIError) and e.code == 400:
                 delete_function_if_exists(client, function_name)
             else:
